@@ -23,11 +23,11 @@ class Locator:
             print("setup.py : " + setup_path)
             exit_success()
         else:
-            stderr("Unable to process your command.  Please enter 'main', 'settings' or 'setup' as the argument to the locate command.", 1)
+            stderr("Unable to process the command.  Use 'naked locate help' for more information.", 1)
 
 def help():
     help_string = """
-Naked locate command help
+Naked locate Command Help
 -------------------------
 
 The Naked locate command identifies the file path to commonly used files in your project directory.
@@ -35,7 +35,7 @@ The Naked locate command identifies the file path to commonly used files in your
 USAGE
   naked locate <argument>
 
-ARGUMENTS
+SECONDARY COMMANDS
   main     -  the main application script file, app.py
   setup    -  the setup.py file
   settings -  the project settings files, settings.py
